import { Utilities } from '@/util/Utilities';
import {
    Modal, ModalService, Text, Form, DialogService, LoadingService, TextInput, Select,
} from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class DescricaoEscopoTabDescricaoEscopoController {
    private basicModal!: Modal;

    public expandir({ component }: any) {
        const form = Metadata.getInstance<Form>(component.name.split('_')[1]);
        form.isVisible = !form.isVisible;

        component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
    }

    public async abrirModalAdicionaDescricaoEscopo() {
        await this.exibirModalDescricaoEscopo();
        Metadata.getInstance<Text>('titleText').text = 'Nova Descrição de Escopo';
    }

    public async exibirModalDescricaoEscopo() {
        this.basicModal = await ModalService.createFromJson('escopoFaturamento/modal/descricaoEscopoModalAddDescricaoEscopo', true);
        this.basicModal.show();
    }

    public fecharModalDescricaoEscopo() {
        this.basicModal.hide();
        this.basicModal?.destroy();
    }

    public inserirDescricaoEscopo() {
        const form = Metadata.getInstance<Form>('form_modal_adiciona_descricao_escopo');
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-descricao-escopo');
        const gridEscopoFaturamento = Metadata.getInstance<TekGrid>('tek-grid-escopo-faturamento_grid');
        const nrdescagrupescopo = Metadata.getInstance<Select>('modalAddDescricaoEscopo-NRDESCAGRUPESCOPO').value;
        const dsnomeagrupamento = Metadata.getInstance<TextInput>('modalAddDescricaoEscopo-DSNOMEAGRUPAMENTO').value;
        const idativo = Metadata.getInstance<Select>('modalAddDescricaoEscopo-IDATIVO').value;
        const idtpfatura = Metadata.getInstance<Select>('modalAddDescricaoEscopo-IDTPFATURA').value;
        const cdempresa = Metadata.getInstance<Select>('modalAddDescricaoEscopo-CDEMPRESA');
        const nrparcfatura = Metadata.getInstance<Select>('modalAddDescricaoEscopo-NRPARCNEGOCIO').value;
        const cdtipooperfatura = Metadata.getInstance<Select>('modalAddDescricaoEscopo-CDTIPOOPER').value;
        const cdserie = Metadata.getInstance<Select>('modalAddDescricaoEscopo-CDSERIE');

        if (Utilities.validateForm(form)) {
            LoadingService.show();
            const params = {
                NRDESCAGRUPESCOPO: nrdescagrupescopo,
                DSNOMEAGRUPAMENTO: dsnomeagrupamento,
                IDATIVO: idativo,
                NRTIPOORCAMENTO: gridEscopoFaturamento.datasource.currentRow.NRTIPOORCAMENTO,
                IDTPFATURA: idtpfatura,
                CDFILIALFATURA: (cdempresa.value === null) ? null : cdempresa.selectValue.CDFILIAL,
                CDEMPRESA: (cdempresa.value === null) ? null : cdempresa.selectValue.CDEMPRESA,
                NRPARCFATURA: nrparcfatura,
                CDTIPOOPERFATURA: cdtipooperfatura,
                CDSERIENF: (cdserie.value === null) ? null : cdserie.selectValue.CDSERIE,
                CDINSCESTA: (cdserie.value === null) ? null : cdserie.selectValue.CDINSCESTA,
                CDINSCMUNI: (cdserie.value === null) ? null : cdserie.selectValue.CDINSCMUNI,
            };

            Http.post('/saveEscFatDescricaoEscopo', params).then(() => {
                this.fecharModalDescricaoEscopo();
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
                if (error.response.data.error === 'EXISTE') {
                    this.showErrorDialogInserirDescricao();
                } else {
                    Utilities.showErrorMessage(error);
                }
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public editDescricaoEscopo() {
        const form = Metadata.getInstance<Form>('descricaoEscopoTab-formRowDadosDescricaoEscopo');
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-descricao-escopo');
        const gridEscopoFaturamento = Metadata.getInstance<TekGrid>('tek-grid-escopo-faturamento_grid');
        const nrdescagrupescopo = Metadata.getInstance<Select>('descricaoEscopoTab-NRDESCAGRUPESCOPO').value;
        const dsnomeagrupamento = Metadata.getInstance<TextInput>('descricaoEscopoTab-DSNOMEAGRUPAMENTO').value;
        const idativo = Metadata.getInstance<Select>('descricaoEscopoTab-IDATIVO').value;
        const idtpfatura = Metadata.getInstance<Select>('descricaoEscopoTab-IDTPFATURA').value;
        const cdempresa = Metadata.getInstance<Select>('descricaoEscopoTab-CDEMPRESA');
        const nrparcfatura = Metadata.getInstance<Select>('descricaoEscopoTab-NRPARCNEGOCIO').value;
        const cdtipooperfatura = Metadata.getInstance<Select>('descricaoEscopoTab-CDTIPOOPER').value;
        const cdserie = Metadata.getInstance<Select>('descricaoEscopoTab-CDSERIE');

        if (Utilities.validateForm(form)) {
            LoadingService.show();
            const params = {
                NRDESCAGRUPESCOPO: nrdescagrupescopo,
                DSNOMEAGRUPAMENTO: dsnomeagrupamento,
                IDATIVO: idativo,
                NRTIPOORCAMENTO: gridEscopoFaturamento.datasource.currentRow.NRTIPOORCAMENTO,
                IDTPFATURA: idtpfatura,
                CDFILIALFATURA: (cdempresa.value === null) ? null : cdempresa.selectValue.CDFILIAL,
                CDEMPRESA: (cdempresa.value === null) ? null : cdempresa.selectValue.CDEMPRESA,
                NRPARCFATURA: nrparcfatura,
                CDTIPOOPERFATURA: cdtipooperfatura,
                CDSERIENF: (cdserie.value === null) ? null : cdserie.selectValue.CDSERIE,
                CDINSCESTA: (cdserie.value === null) ? null : cdserie.selectValue.CDINSCESTA,
                CDINSCMUNI: (cdserie.value === null) ? null : cdserie.selectValue.CDINSCMUNI,
            };

            Http.post('/saveEscFatDescricaoEscopo', params).then(() => {
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
                if (error.response.data.error === 'EXISTE') {
                    this.showErrorDialogInserirDescricao();
                } else {
                    Utilities.showErrorMessage(error);
                }
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public showErrorDialogInserirDescricao() {
        DialogService.show({
            name: 'error-dialog-validacao-descEscopo',
            type: 'error',
            title: 'Atenção',
            text: 'Operação Bloqueanda! Já existe uma descrição cadastrada para estas parametrizações.',
        });
    }

    public showConfirmDeleteMessageDescricaoEscopo({ event }: any) {
        event!.preventDefault();
        DialogService.show({
            name: 'buttons-dialog-operador',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deleteEscFatDescricaoEscopo();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deleteEscFatDescricaoEscopo() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-descricao-escopo');
        LoadingService.show();
        Http.post('/deleteEscFatDescricaoEscopo', grid.selectedRows)
            .then(() => {
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
    }
}
