import { Utilities } from '@/util/Utilities';
import {
    DialogService,
    Form,
    LoadingService,
    Modal, ModalService, Select, Text, TextInput,
} from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class Sm00005000TabParametrizacoesServicesEmailController {
    private basicModal!: Modal;

    public currentRow: any = {
        NRPARAMEMAILFILIAL: null,
    };

    public async exibirModalEmail() {
        this.basicModal = await ModalService.createFromJson('sm_00005_000_parametrizacoes_services/modal/sm_00005_000_parametrizacoes_services_emails_modal', true);
        this.basicModal.show();
    }

    public fecharModalEmail() {
        this.basicModal.hide();
        this.basicModal?.destroy();
    }

    public async abrirModalEmailInsert() {
        await this.exibirModalEmail();
        Metadata.getInstance<Text>('titleText').text = 'Novo Registro';
    }

    public async abrirModalEmailEdicao({ row }: any) {
        await this.exibirModalEmail();
        this.currentRow.NRPARAMEMAILFILIAL = row.NRPARAMEMAILFILIAL;
        Metadata.getInstance<Text>('titleText').text = 'Edição de Registro';
        Metadata.getInstance<Select>('CDFILIAL').value = row.CDFILIAL;
        Metadata.getInstance<TextInput>('DSREMETENTEEMAIL').value = row.DSREMETENTEEMAIL;
        Metadata.getInstance<TextInput>('DSASSUNTOEMAIL').value = row.DSASSUNTOEMAIL;
        Metadata.getInstance<TextInput>('DSCORPOEMAIL').value = row.DSCORPOEMAIL;
    }

    public changeEmail({ component }: any) {
        const result = this.validarEmail(component.value);
        if (result === false) {
            Utilities.showDialogMessage('error', 'Operação Bloqueada!', 'E-mail inválido');
        }
    }

    public validarEmail(email: any) {
        const re = /\S+@\S+\.\S+/;
        return re.test(email);
    }

    public saveParameterEmail() {
        const form = Metadata.getInstance<Form>('form_modal_email');
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-emails');
        if (Utilities.validateForm(form)) {
            LoadingService.show();
            Http.post('/saveParameterEmail', {
                CDFILIAL: Metadata.getInstance<Select>('CDFILIAL').value,
                DSREMETENTEEMAIL: Metadata.getInstance<TextInput>('DSREMETENTEEMAIL').value,
                DSASSUNTOEMAIL: Metadata.getInstance<TextInput>('DSASSUNTOEMAIL').value,
                DSCORPOEMAIL: Metadata.getInstance<TextInput>('DSCORPOEMAIL').value,
                NRPARAMEMAILFILIAL: this.currentRow.NRPARAMEMAILFILIAL,
            }).then(() => {
                this.fecharModalEmail();
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error) => {
                if (error.response.data.error === 'EXISTE') {
                    Utilities.showDialogMessage('error', 'Operação bloqueada!', 'Filial selecionada já possui e-mail parametrizado.');
                } else {
                    Utilities.showErrorMessage(error);
                }
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public showConfirmDeleteMessage({ event }: any) {
        event!.preventDefault();
        DialogService.show({
            name: 'buttons-dialog-operador',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deleteParametrosEmail();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deleteParametrosEmail() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-emails');
        LoadingService.show();
        Http.post('/deleteParametrosEmail', grid.selectedRows)
            .then(() => {
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
    }
}
